.. _Authentication:

Authentication
==============

Authentication process based on "user token" and "chat token".

Each Api's request has parameters:

* ``chat token`` to identify chat
* ``user token`` to identify user

More details in :ref:`diagrams <Diagrams>`.
